@@ -3,18 +3,18 @@
 #
 #   Copyright (C) 2008 Rocky Bernstein rocky@gnu.org
 #
-#   bashdb is free software; you can redistribute it and/or modify it under
-#   the terms of the GNU General Public License as published by the Free
-#   Software Foundation; either version 2, or (at your option) any later
-#   version.
+#   This program is free software; you can redistribute it and/or
+#   modify it under the terms of the GNU General Public License as
+#   published by the Free Software Foundation; either version 2, or
+#   (at your option) any later version.
 #
-#   bashdb is distributed in the hope that it will be useful, but WITHOUT ANY
-#   WARRANTY; without even the implied warranty of MERCHANTABILITY or
-#   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-#   for more details.
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+#   General Public License for more details.
 #   
 #   You should have received a copy of the GNU General Public License along
-#   with bashdb; see the file COPYING.  If not, write to the Free Software
+#   with this program; see the file COPYING.  If not, write to the Free Software
 #   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
 
 _Dbg_help_add alias \
@@ -26,8 +26,10 @@ aliases in effect.'
 _Dbg_do_alias() {
   if (($# != 2)) ; then
       _Dbg_errmsg "Got $# parameters, but need 2."
+      return 1
   fi
   _Dbg_alias_add $1 $2
+  return $?
 }
 
 _Dbg_help_add unalias \
@@ -38,6 +40,8 @@ Use "show aliases" to get a list the aliases in effect.'
 _Dbg_do_unalias() {
   if (($# != 1)) ; then
       _Dbg_errmsg "Got $# parameters, but need 1."
+      return 1
   fi
   _Dbg_alias_remove $1
+  return 0
 }
