@@ -1,19 +1,20 @@
 # -*- shell-script -*-
-#   Copyright (C) 2008 Rocky Bernstein rocky@gnu.org
+#   Copyright (C) 2008, 2010 Rocky Bernstein <rocky@gnu.org>
 #
-#   bashdb is free software; you can redistribute it and/or modify it under
-#   the terms of the GNU General Public License as published by the Free
-#   Software Foundation; either version 2, or (at your option) any later
-#   version.
+#   This program is free software; you can redistribute it and/or
+#   modify it under the terms of the GNU General Public License as
+#   published by the Free Software Foundation; either version 2, or
+#   (at your option) any later version.
 #
-#   bashdb is distributed in the hope that it will be useful, but WITHOUT ANY
-#   WARRANTY; without even the implied warranty of MERCHANTABILITY or
-#   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-#   for more details.
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+#   General Public License for more details.
 #   
-#   You should have received a copy of the GNU General Public License along
-#   with bashdb; see the file COPYING.  If not, write to the Free Software
-#   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+#   You should have received a copy of the GNU General Public License
+#   along with this program; see the file COPYING.  If not, write to
+#   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
+#   MA 02111 USA.
 
 _Dbg_help_add break \
 'break [LOCSPEC] -- Set a breakpoint at LOCSPEC. 
@@ -32,59 +33,72 @@ by using "delete" on the breakpoint number.
 
 If no location specification is given, use the current line.'
 
-# Add breakpoint(s) at given line number of the current file.  $1 is
-# the line number or _curline if omitted.  $2 is a condition to test
-# for whether to stop.
+_Dbg_do_tbreak() {
+    _Dbg_do_break_common 1 $@
+    return $?
+}
+
 _Dbg_do_break() {
+    _Dbg_do_break_common 0 $@
+    return $?
+}
 
-  typeset -i is_temp=$1
-  shift
+# Add breakpoint(s) at given line number of the current file.  $1 is
+# the line number or _Dbg_frame_lineno if omitted.  $2 is a condition
+# to test for whether to stop.
+_Dbg_do_break_common() {
 
-  typeset linespec
-  if (( $# > 0 )) ; then 
-      linespec="$1"
-  else
-      linespec="$_curline"
-  fi
-  shift
-
-  typeset condition=${1:-''}
-  if [[ "$linespec" == 'if' ]]; then
-    linespec=$_curline
-  elif [[ -z $condition ]] ; then
-    condition=1
-  elif [[ $condition == 'if' ]] ; then
+    typeset -i is_temp=$1
     shift
-  fi
-  if [[ -z $condition ]] ; then
-    condition=1
-  else 
-    condition="$*"
-  fi
 
-  typeset filename
-  typeset -i line_number
-  typeset full_filename
-
-  _Dbg_linespec_setup "$linespec"
-
-  if [[ -n "$full_filename" ]]  ; then 
-    if (( line_number ==  0 )) ; then 
-      _Dbg_errmsg 'There is no line 0 to break at.'
-    else 
-      _Dbg_check_line $line_number "$full_filename"
-      (( $? == 0 )) && \
-	_Dbg_set_brkpt "$full_filename" "$line_number" $is_temp "$condition"
+    typeset linespec
+    if (( $# > 0 )) ; then 
+	linespec="$1"
+    else
+	linespec="$_Dbg_frame_last_lineno"
     fi
-  else
-    _Dbg_file_not_read_in "$filename"
-  fi
+    shift
+    
+    typeset condition=${1:-''}
+    if [[ "$linespec" == 'if' ]]; then
+	linespec=$_Dbg_frame_last_lineno
+    elif [[ -z $condition ]] ; then
+	condition=1
+    elif [[ $condition == 'if' ]] ; then
+	shift
+    fi
+    if [[ -z $condition ]] ; then
+	condition=1
+    else 
+	condition="$*"
+    fi
+    
+    typeset filename
+    typeset -i line_number
+    typeset full_filename
+    
+    _Dbg_linespec_setup "$linespec"
+    
+    if [[ -n "$full_filename" ]]  ; then 
+	if (( line_number ==  0 )) ; then 
+	    _Dbg_errmsg 'There is no line 0 to break at.'
+	    return 1
+	else 
+	    _Dbg_check_line $line_number "$full_filename"
+	    (( $? == 0 )) && \
+		_Dbg_set_brkpt "$full_filename" "$line_number" $is_temp "$condition"
+	fi
+    else
+	_Dbg_file_not_read_in "$full_filename"
+	return 2
+    fi
+    return 0
 }
 
 # delete brkpt(s) at given file:line numbers. If no file is given
 # use the current file.
 _Dbg_do_clear_brkpt() {
-  typeset -r n=${1:-$_curline}
+  typeset -r n=${1:-$_Dbg_frame_lineno}
 
   typeset filename
   typeset -i line_number
@@ -95,6 +109,7 @@ _Dbg_do_clear_brkpt() {
   if [[ -n $full_filename ]] ; then 
     if (( $line_number ==  0 )) ; then 
       _Dbg_msg "There is no line 0 to clear."
+      return 0
     else 
       _Dbg_check_line $line_number "$full_filename"
       if (( $? == 0 )) ; then
@@ -102,13 +117,13 @@ _Dbg_do_clear_brkpt() {
 	typeset -r found=$?
 	if [[ $found != 0 ]] ; then 
 	  _Dbg_msg "Removed $found breakpoint(s)."
-	else 
-	  _Dbg_msg "Didn't find any breakpoints to remove at $n."
+	  return $found
 	fi
       fi
     fi
   else
-    _Dbg_file_not_read_in "$filename"
+    _Dbg_file_not_read_in "$full_filename"
+    return 0
   fi
 }
 
@@ -154,13 +169,15 @@ _Dbg_do_list_brkpt() {
 	if [[ ${_Dbg_brkpt_cond[$i]} != '1' ]] ; then
 	  _Dbg_printf "\tstop only if %s" "${_Dbg_brkpt_cond[$i]}"
 	fi
-	if (( _Dbg_brkpt_count[$i] != 0 )) ; then
-	  _Dbg_print_brkpt_count ${_Dbg_brkpt_count[$i]}
+	if (( _Dbg_brkpt_counts[$i] != 0 )) ; then
+	  _Dbg_print_brkpt_count ${_Dbg_brkpt_counts[$i]}
 	fi
       fi
     done
+    return 0
   else
     _Dbg_msg 'No breakpoints have been set.'
+    return 1
   fi
 }
 
