@@ -1,22 +1,23 @@
 # -*- shell-script -*-
-# restart.sh - gdb-like "restart" debugger command
+# gdb-like "restart" debugger command
 #
-#   Copyright (C) 2002, 2003, 2004, 2006, 2008, 2009 Rocky Bernstein 
-#   rocky@gnu.org
+#   Copyright (C) 2002, 2003, 2004, 2006, 2008, 2009, 2010 Rocky Bernstein 
+#   <rocky@gnu.org>
 #
-#   bashdb is free software; you can redistribute it and/or modify it under
-#   the terms of the GNU General Public License as published by the Free
-#   Software Foundation; either version 2, or (at your option) any later
-#   version.
+#   This program is free software; you can redistribute it and/or
+#   modify it under the terms of the GNU General Public License as
+#   published by the Free Software Foundation; either version 2, or
+#   (at your option) any later version.
 #
-#   bashdb is distributed in the hope that it will be useful, but WITHOUT ANY
-#   WARRANTY; without even the implied warranty of MERCHANTABILITY or
-#   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-#   for more details.
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+#   General Public License for more details.
 #   
-#   You should have received a copy of the GNU General Public License along
-#   with bashdb; see the file COPYING.  If not, write to the Free Software
-#   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+#   You should have received a copy of the GNU General Public License
+#   along with this program; see the file COPYING.  If not, write to
+#   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
+#   MA 02111 USA.
 
 # Restart script in same way with saved arguments (probably the same
 # ones as we were given before).
@@ -46,9 +47,9 @@ _Dbg_do_restart() {
 	else
 	    script_args="${bash_opt}$_Dbg_orig_0 $script_args";
 	fi
-	exec_cmd_prefix="$BASH $script_args"
+	exec_cmd_prefix="$BASH"
     elif [[ -n "$BASH" ]] ; then
-	local exec_cmd_prefix="$BASH $_Dbg_orig_0 $script_args"
+	local exec_cmd_prefix="$BASH $_Dbg_orig_0"
     fi
 
     _Dbg_msg "Restarting with: $script_args"
