@@ -1,21 +1,22 @@
 # -*- shell-script -*-
-# dbg-opts.sh - bashdb command options processing. The bane of programming.
+# dbg-opts.sh - debugger command options processing. The bane of programming.
 #
-#   Copyright (C) 2008, 2009 Rocky Bernstein rocky@gnu.org
+#   Copyright (C) 2008, 2009, 2010 Rocky Bernstein <rocky@gnu.org>
 #
-#   bashdb is free software; you can redistribute it and/or modify it under
-#   the terms of the GNU General Public License as published by the Free
-#   Software Foundation; either version 2, or (at your option) any later
-#   version.
+#   This program is free software; you can redistribute it and/or
+#   modify it under the terms of the GNU General Public License as
+#   published by the Free Software Foundation; either version 2, or
+#   (at your option) any later version.
 #
-#   bashdb is distributed in the hope that it will be useful, but WITHOUT ANY
-#   WARRANTY; without even the implied warranty of MERCHANTABILITY or
-#   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-#   for more details.
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+#   General Public License for more details.
 #   
-#   You should have received a copy of the GNU General Public License along
-#   with bashdb; see the file COPYING.  If not, write to the Free Software
-#   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+#   You should have received a copy of the GNU General Public License
+#   along with this program; see the file COPYING.  If not, write to
+#   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
+#   MA 02111 USA.
 
 _Dbg_usage() {
   printf "Usage: 
@@ -36,6 +37,8 @@ options:
     -V | --version          Print the debugger version number.
     -x | --eval-command CMDFILE
                             Execute debugger commands from CMDFILE.
+    --tty | --terminal      Set terminal to output to
+    --tempdir DIRECTORY     Set diretory to use for writing temporary files.
 "
   exit 100
 }
@@ -59,11 +62,11 @@ eval "_Dbg_orig_script_args=(\"\$@\")"
 typeset    _Dbg_tmpdir=/tmp
 
 # Use gdb-style annotate?
-typeset -i _Dbg_annotate=0
+typeset -i _Dbg_set_annotate=0
 
 # Simulate set -x?
 typeset -i _Dbg_linetrace=0
-typeset -i _Dbg_basename_only=0
+typeset -i _Dbg_set_basename=0
 typeset -i _Dbg_o_nx=0
 
 
@@ -86,6 +89,8 @@ _Dbg_parse_options() {
 	nx       0                           \
 	quiet    0                           \
         tempdir  required_argument           \
+        tty      required_argument           \
+        terminal required_argument           \
 	version  0                           \
 	'' "$@"
     do
@@ -93,7 +98,7 @@ _Dbg_parse_options() {
 	    A | annotate ) 
 		_Dbg_o_annotate=$OPTLARG;;
 	    B | basename )
-		_Dbg_basename_only=1  	;;
+		_Dbg_set_basename=1  	;;
 	    c | command )
 		_Dbg_EXECUTION_STRING="$OPTLARG" ;;
 	    debugger ) 
@@ -136,10 +141,11 @@ _Dbg_parse_options() {
     if (( _Dbg_o_version )) ; then
 	_Dbg_do_show_version
 	exit 0
-    elif (( ! _Dbg_o_quiet )) && [[ -n "$_Dbg_shell_name" ]] ; then 
-	echo "$_Dbg_shell_name Shell Debugger, release $_Dbg_release"
+    elif (( ! _Dbg_o_quiet )) && [[ -n $_Dbg_shell_name ]] && \
+	[[ -n $_Dbg_release ]] ; then 
+	echo "$_Dbg_debugger_name debugger, release $_Dbg_release"
 	printf '
-Copyright 2002, 2003, 2004, 2006, 2007, 2008, 2009 Rocky Bernstein
+Copyright 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010 Rocky Bernstein
 This is free software, covered by the GNU General Public License, and you are
 welcome to change it and/or distribute copies of it under certain conditions.
 
@@ -149,11 +155,11 @@ welcome to change it and/or distribute copies of it under certain conditions.
 
     if [[ -n $_Dbg_o_annotate ]] ; then
 	if [[ ${_Dbg_o_annotate} == [0-9]* ]] ; then
-	    _Dbg_annotate=$_Dbg_o_annotate
-	    if (( _Dbg_annotate > 3 || _Dbg_annotate < 0)); then
-		echo "Annotation level must be less between 0 and 3. Got: $_Dbg_annotate." >&2
+	    _Dbg_set_annotate=$_Dbg_o_annotate
+	    if (( _Dbg_set_annotate > 3 || _Dbg_set_annotate < 0)); then
+		echo "Annotation level must be less between 0 and 3. Got: $_Dbg_set_annotate." >&2
 		echo "Setting Annotation level to 0." >&2
-		_Dbg_annotate=0
+		_Dbg_set_annotate=0
 	    fi
 	else
 	    echo "Annotate option should be an integer, got ${_Dbg_o_annotate}." >&2
@@ -171,7 +177,7 @@ if [[ -n "$_Dbg_dbg_opts_test" ]] ; then
     _Dbg_libdir='.'
     [[ -n $_Dbg_input ]] && typeset -p _Dbg_input
     _Dbg_parse_options "$@"
-    typeset -p _Dbg_annotate
+    typeset -p _Dbg_set_annotate
     typeset -p _Dbg_linetrace
-    typeset -p _Dbg_basename_only
+    typeset -p _Dbg_set_basename
 fi
