@@ -1,5 +1,5 @@
 # -*- shell-script -*-
-#   Copyright (C) 2008 Rocky Bernstein rocky@gnu.org
+#   Copyright (C) 2008, 2010 Rocky Bernstein rocky@gnu.org
 #
 #   bashdb is free software; you can redistribute it and/or modify it under
 #   the terms of the GNU General Public License as published by the Free
@@ -16,44 +16,34 @@
 #   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
 
 # Command aliases are stored here.
-typeset -a _Dbg_alias_names=()
-typeset -a _Dbg_alias_expansion=()
-typeset -i _Dbg_alias_max_index=-1
+typeset -A _Dbg_aliases
 
 # Add an new alias in the alias table
 _Dbg_alias_add() {
     (( $# != 2 )) && return 1
-    ((_Dbg_alias_max_index++))
-    _Dbg_alias_names+=("$1")
-    _Dbg_alias_expansion+=("$2")
+    _Dbg_aliases[$1]="$2"
      return 0
 }
 
 # Remove alias $1 from our list of command aliases.
 _Dbg_alias_remove() {
     (( $# != 1 )) && return 1
-    typeset -i i
-    if i=$(_Dbg_alias_find_index "$1") ; then
-      unset "_Dbg_alias_names[$i]"
-      unset "_Dbg_alias_expansion[$i]"
-      return 0
-    else
-      return 1
-    fi
+    unset "_Dbg_aliases[$1]"
+    return 0
 }
 
 # Expand alias $1. The result is set in variable expanded_alias which
 # could be declared local in the caller.
 _Dbg_alias_expand() {
     (( $# != 1 )) && return 1
-    expanded_alias=$1
-    typeset -i i
-    i=$(_Dbg_alias_find_index "$1")
-    (( $? == 0 )) && [[ -n ${_Dbg_alias_expansion[$i]} ]] && expanded_alias=${_Dbg_alias_expansion[$i]}
+    expanded_alias="$1"
+    [[ -z "$1" ]] && return 0
+    [[ -n ${_Dbg_aliases[$1]} ]] && expanded_alias=${_Dbg_aliases[$1]}
     return 0
 }
 
-# Return the index in _Dbg_command_names of $1 or -1 if not there.
+# Echo the index in _Dbg_command_names if found. Return
+# 0 if found and 1 if not there.
 _Dbg_alias_find_index() {
     typeset find_name=$1
     typeset -i i
@@ -70,13 +60,12 @@ _Dbg_alias_find_aliased() {
     typeset find_name=$1
     aliases_found=''
     typeset -i i
-    for ((i=0; i <= $_Dbg_alias_max_index; i++)) ; do
-	if [[ ${_Dbg_alias_expansion[i]} == "$find_name" ]] ; then 
+    for alias in ${!_Dbg_aliases[@]} ; do
+	if [[ ${_Dbg_aliases[$alias]} == "$find_name" ]] ; then 
 	    [[ -n $aliases_found ]] && aliases_found+=', '
-	    aliases_found+=${_Dbg_alias_names[i]}
+	    aliases_found+="$alias"
 	fi
     done
     return 0
-    
 }
 
