@@ -4,19 +4,57 @@
 #   Copyright (C) 2002, 2003, 2004, 2006, 2008, 2009 Rocky Bernstein 
 #   rocky@gnu.org
 #
-#   bashdb is free software; you can redistribute it and/or modify it under
-#   the terms of the GNU General Public License as published by the Free
-#   Software Foundation; either version 2, or (at your option) any later
-#   version.
+#   This program is free software; you can redistribute it and/or
+#   modify it under the terms of the GNU General Public License as
+#   published by the Free Software Foundation; either version 2, or
+#   (at your option) any later version.
 #
-#   Bashdb is distributed in the hope that it will be useful, but WITHOUT ANY
-#   WARRANTY; without even the implied warranty of MERCHANTABILITY or
-#   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-#   for more details.
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+#   General Public License for more details.
 #   
-#   You should have received a copy of the GNU General Public License along
-#   with Bashdb; see the file COPYING.  If not, write to the Free Software
-#   Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+#   You should have received a copy of the GNU General Public License
+#   along with this program; see the file COPYING.  If not, write to
+#   the Free Software Foundation, 59 Temple Place, Suite 330, Boston,
+#   MA 02111 USA.
+
+_Dbg_confirm() {
+    if (( $# < 1 || $# > 2 )) ; then
+	_Dbg_response='error'
+	return 0
+    fi
+    _Dbg_confirm_prompt=$1
+    typeset _Dbg_confirm_default=${2:-'no'}
+    while : ; do 
+	if ! read $_Dbg_edit -p "$_Dbg_confirm_prompt" _Dbg_response args \
+	    <&$_Dbg_input_desc 2>>$_Dbg_prompt_output ; then
+	    break
+	fi
+
+	case "$_Dbg_response" in
+	    'y' | 'yes' | 'yeah' | 'ya' | 'ja' | 'si' | 'oui' | 'ok' | 'okay' )
+		_Dbg_response='y'
+		return 0
+		;;
+	    'n' | 'no' | 'nope' | 'nyet' | 'nein' | 'non' )
+		_Dbg_response='n'
+		return 0
+		;;
+	    *)
+		if [[ $_Dbg_response =~ '^[ \t]*$' ]] ; then
+		    set +x
+		    return 0
+		else
+		    _Dbg_msg "I don't understand \"$_Dbg_response\"."
+		    _Dbg_msg "Please try again entering 'yes' or 'no'."
+		    _Dbg_response=''
+		fi
+		;;
+	esac
+
+    done
+}
 
 # Print an error message
 function _Dbg_errmsg {
@@ -60,72 +98,24 @@ function _Dbg_msg_nocr {
 
 # print message to output device
 function _Dbg_printf {
-  typeset format=$1
-  shift
-  if (( _Dbg_logging )) ; then
-    builtin printf "$format" "$@" >>$_Dbg_logfid
-  fi
-  if (( ! _Dbg_logging_redirect )) ; then
-    if [[ -n $_Dbg_tty ]] ; then
-      builtin printf "$format" "$@" >>$_Dbg_tty
-    else
-      builtin printf "$format" "$@"
-    fi
-  fi
-  _Dbg_msg ''
+    _Dbg_printf_nocr "$@"
+    _Dbg_msg ''
 }
 
 # print message to output device without a carriage return at the end
 function _Dbg_printf_nocr {
-  typeset format=$1
-  shift 
-  if (( _Dbg_logging )) ; then
-    builtin printf "$format" "$@" >>$_Dbg_logfid
-  fi
-  if (( ! _Dbg_logging_redirect )) ; then
-    if [[ -n $_Dbg_tty ]] ; then 
-      builtin printf "$format" "$@" >>$_Dbg_tty
-    else
-      builtin printf "$format" "$@"
+    typeset format=$1
+    shift 
+    if (( _Dbg_logging )) ; then
+	builtin printf "$format" "$@" >>$_Dbg_logfid
     fi
-  fi
-}
-
-_Dbg_confirm() {
-    if (( $# < 1 || $# > 2 )) ; then
-	_Dbg_response='error'
-	return 0
-    fi
-    _Dbg_confirm_prompt=$1
-    typeset _Dbg_confirm_default=${2:-'no'}
-    while : ; do 
-	if ! read $_Dbg_edit -p "$_Dbg_confirm_prompt" _Dbg_response args \
-	    <&$_Dbg_input_desc 2>>$_Dbg_prompt_output ; then
-	    break
+    if (( ! _Dbg_logging_redirect )) ; then
+	if [[ -n $_Dbg_tty ]] ; then 
+	    builtin printf "$format" "$@" >>$_Dbg_tty
+	else
+	    builtin printf "$format" "$@"
 	fi
-
-	case "$_Dbg_response" in
-	    'y' | 'yes' | 'yeah' | 'ya' | 'ja' | 'si' | 'oui' | 'ok' | 'okay' )
-		_Dbg_response='y'
-		return 0
-		;;
-	    'n' | 'no' | 'nope' | 'nyet' | 'nein' | 'non' )
-		_Dbg_response='n'
-		return 0
-		;;
-	    *)
-		if [[ $_Dbg_response =~ '^[ \t]*$' ]] ; then
-		    set +x
-		    return 0
-		else
-		    _Dbg_msg "I don't understand \"$_Dbg_response\"."
-		    _Dbg_msg "Please try again entering 'yes' or 'no'."
-		    _Dbg_response=''
-		fi
-		;;
-	esac
-
-    done
+    fi
 }
 
 # Common funnel for "Undefined command" message
