@@ -17,7 +17,7 @@ test_alias()
 
     _Dbg_alias_add exit quit
     _Dbg_alias_find_aliased quit
-    assertEquals 'q, exit' "$aliases_found"
+    assertEquals 'exit, q' "$aliases_found"
 
     _Dbg_alias_remove q
     expanded_alias=''; _Dbg_alias_expand q
@@ -42,7 +42,5 @@ abs_top_srcdir=${abs_top_srcdir%%/}/
 . $abs_top_srcdir/lib/alias.sh
 
 # load shunit2
-
-srcdir=.
-srcdir=${srcdir}/
-. ${srcdir}/shunit2
+shunit_file=${abs_top_srcdir}test/unit/shunit2
+. ${shunit_file}
