@@ -17,7 +17,7 @@ test_preserve_set_opts()
 	# Name we refer to ourselves by
 	typeset _Dbg_debugger_name='bashdb'
 	# The release name we are configured to run under.
-	typeset _Dbg_release='4.0-0.4'
+	typeset _Dbg_release='4.2-0.6'
 	. ${top_builddir}/bashdb-trace -L $libdir
 	assertEquals $old_opts $-
     else
@@ -33,9 +33,10 @@ test_preserve_set_opts()
 prefix=/usr/local
 top_builddir=/src/external-vcs/bashdb
 top_srcdir=/src/external-vcs/bashdb
+. ${top_srcdir}/lib/filecache.sh
 . ${top_srcdir}/lib/sig.sh
 . ${top_srcdir}/lib/help.sh
-. ${top_srcdir}/command/tracefn.sh
+. ${top_srcdir}/command/trace.sh
 
 srcdir=.
 srcdir=${srcdir}/
