@@ -1,13 +1,37 @@
 #!/bin/bash
 # -*- shell-script -*-
 
+# Test _Dbg_file_canonic
+test_file_canonic()
+{
+    _Dbg_set_basename=0
+    for file in /tmp/foo.bar /a/b/foo.bar foo.bar ; do 
+	typeset canonic_file
+	canonic_file=$(_Dbg_file_canonic "$file")
+	assertEquals 'canonic_file should return 0' '0' $?
+	assertEquals 'canonic_file should do nothing' "$file" "$canonic_file"
+    done
+
+    _Dbg_set_basename=1
+    typeset canonic_file
+    for file in /tmp/foo.bar /a/b/foo.bar foo.bar ; do 
+	canonic_file=$(_Dbg_file_canonic "$file")
+	assertEquals 'canonic_file should return 0' '0' $?
+	assertEquals 'canonic_file should shorten file' 'foo.bar' "$canonic_file"
+    done
+    canonic_file=$(_Dbg_file_canonic)
+    assertNotEquals 'canonic_file not should return 0' '0' $?
+    # Other tests need _Dbg_set_basename = 0
+    _Dbg_set_basename=0
+}
+
 # Test _Dbg_glob_filename
 test_glob_filename()
 {
     typeset filename
 
     filename=''
-    _Dbg_glob_filename ${srcdir}shunit2
+    _Dbg_glob_filename $shunit_file
     assertEquals '0' $?
     filename=${filename##*/}  
     assertEquals 'shunit2' $filename
@@ -44,13 +68,13 @@ test_glob_filename()
 test_adjust_filename()
 {
     typeset filename
-    _Dbg_annotate=0
+    _Dbg_set_annotate=0
     _Dbg_basename=0
     filename=$(_Dbg_adjust_filename abc)
     assertEquals 'abc' $filename
     filename=$(_Dbg_adjust_filename /abc)
     assertEquals '/abc' $filename
-    _Dbg_basename_only=1
+    _Dbg_set_basename=1
     filename=$(_Dbg_adjust_filename /abc)
     assertEquals 'abc' $filename
 }
@@ -80,10 +104,9 @@ srcdir=${srcdir%%/}/
 _Dbg_libdir=$abs_top_srcdir
 set -- -q  # Don't need to show banner
 . $abs_top_srcdir/dbg-pre.sh
-. $abs_top_srcdir/lib/fns.sh
+. $abs_top_srcdir/lib/filecache.sh
 . $abs_top_srcdir/lib/file.sh
 
 # load shunit2
-. ${abs_top_srcdir}/test/unit/shunit2
-
-
+shunit_file=${abs_top_srcdir}test/unit/shunit2
+. ${shunit_file}
