@@ -26,7 +26,7 @@ _Dbg_libdir=$abs_top_srcdir
 set -- -q  # Don't need to show banner
 . ${abs_top_srcdir}/dbg-pre.sh
 . ${abs_top_srcdir}/lib/journal.sh
-. ${abs_top_srcdir}/lib/fns.sh
+. ${abs_top_srcdir}/lib/filecache.sh
 . ${abs_top_srcdir}/lib/file.sh
 . ${abs_top_srcdir}/lib/save-restore.sh
 
