@@ -31,7 +31,11 @@ test_sort()
     check=(1 2 3 4)
     do_one
     list=(' 4' '3 ' '2' '1')
-    check=(' 4' '1' '2' '3 ')
+    if [[ ' 4' < '1' ]] ; then
+	check=(' 4' '1' '2' '3 ')
+    else
+	check=('1' '2' '3 ' ' 4')
+    fi
     do_one
 
     sort_list 0 10 
@@ -39,11 +43,11 @@ test_sort()
 }
 
 
-if [ '/src/external-cvs/bashdb-3.1' = '' ] ; then
+if [ '/src/external-vcs/bashdb' = '' ] ; then
   echo "Something is wrong abs_top_srcdir is not set."
  exit 1
 fi
-abs_top_srcdir=/src/external-cvs/bashdb-3.1
+abs_top_srcdir=/src/external-vcs/bashdb
 # Make sure @abs_top_srcr@ has a trailing slash
 abs_top_srcdir=${abs_top_srcdir%%/}/
 
